#
# spec file for package js8call
#
# Copyright (c) 2018-2025 Walter Fey DL8FCL
#
# This file is under MIT license

Name:           js8call
Version:        2.2.1
Release:        2.1
Summary:        Weak-signal amateur radio communications
License:        GPL-3.0
Group:          Productivity/Hamradio/Other
Url:            http://js8call.com/
Source0:        %{name}-%{version}.tar.xz
Source1:        js8call-rpmlintrc
Patch0:         js8call-version.diff
Patch1:         js8call-hamlib_static_0.diff
Patch2:         js8call-no-return-in-nonvoid-function.diff
Patch3:         js8call-hamlib-RIGCAPS_NOT_CONST.diff

BuildRequires:  cmake
BuildRequires:  fftw3-threads-devel
BuildRequires:  gcc-fortran
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(hamlib)
BuildRequires:  pkgconfig(libudev)

%description
JS8Call is a derivative of the WSJT-X application, restructured and redesigned
for keyboard-to-keyboard message passing.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

%build
%if 0%{?suse_version} > 1500
%cmake -Dhamlib_INCLUDE_DIRS=%{_includedir} \
       -Dhamlib_LIBRARIES=%{_libdir}/libhamlib.so \
       -Dhamlib_LIBRARY_DIRS=%{_libdir} \
       -DCMAKE_CXX_FLAGS="${CMAKE_CXX_FLAGS}"
%else
%cmake -Dhamlib_INCLUDE_DIRS=%{_includedir} \
       -Dhamlib_LIBRARIES=%{_libdir}/libhamlib.so \
       -Dhamlib_LIBRARY_DIRS=%{_libdir}
%endif
%cmake_build

%install
%cmake_install
rm -r %{buildroot}%{_datadir}/doc

%suse_update_desktop_file -i -r %{name} "Network;HamRadio"

%files
%doc README
%license COPYING
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}_icon.png

%changelog
* Sat Jan  4 2025 Walter Fey <dl8fcl@darc.de>
- Improved fix for hamlib changes
* Sat Nov 25 2023 Walter Fey <dl8fcl@darc.de>
- Fix for latest hamlib changes
* Wed Mar  9 2022 Walter Fey <dl8fcl@darc.de>
- update to version 2.2.1 dev
  * no functional difference to 2.2.0
* Sat Jun 27 2020 Walter Fey <dl8fcl@darc.de>
- update to version 2.2.0
  * js8call-HamlibTransceiver.diff deleted. Fixed upstream.
  * A new decoder that is more sensitive, more accurate, and more stable.
  * An option to enable automatic time synchronization with stations in the passband.
  * An option to require confirmation for any automatic replies sent from your station.
  * Some new built-in group callsigns for sending messages/commands to groups
    efficiently.
  * A new JS8Call API that is easier to use and which includes more real-time
    information coming out of the app.
  * A new display format for heartbeats.
  * Related, responses to heartbeats will be sent using a new SNR command
    instead of the old ACK command. The new response will look like: HEARTBEAT SNR -5
  * You can now easily disable the transmitter (just like the receiver) using
    the menu or by clicking the TX button.
  * The dropped frame indicator is now configurable (... by default)
  * The waterfall can now visually display when the decoder attempts to decode
    a signal. Useful for seeing where all of your CPU is going.
  * And many many many bugfixes and usability improvements.
* Fri Mar 20 2020 Walter Fey <dl8fcl@darc.de>
- js8call-HamlibTransceiver.diff to fix changes in hamlib
* Wed Dec 25 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.1.1
- Added decoder threshold extension for slow mode to prevent decode thrashing after tx
- Added center filter spinbox implementation
- Added ability to use legacy hamlib vfo definition
- Added filter width parameter. Added filter center right click option.
- Fixed ordering of filter controls and logic around min filter
- Fixed table sorting by slow speed
- Fixed widegraph width issues on larger monitors by centering the widegraph
  and extending the controls panel
- Filter center, width, and min. Much easier to use. No cumbersome jumping around.
- Spinbox label tweaks
* Mon Dec 23 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.1.0
- A new slow speed with a 30 second transmission for decoding down to -28dB.
- Software filter to limit the frequencies that the decoder will try to decode.
- Some tweaks to the decoder to allow it to be slightly more sensitive.
- hamlib_rig.h.diff removed. Fixed upstream.
* Thu Dec  5 2019 Walter Fey <dl8fcl@darc.de>
- hamlib_rig.h.diff to fix latest changes in hamlib
* Mon Dec  2 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.0.1
- Fixed issue with WideGraph activating on Windows before fully.
  initialized, which when notifications were enabled (not sure why)
  would hang the widegraph.
* Fri Nov 29 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.0.0-GA
  - Fixed newline processing
  - Fixed enter keypress for proper handling
  - Fixed #71: newline supported in 2.0 messages
  - Hide save audio functionality until its no longer broken
  - Turn off decoder debugging by default unless in debug mode
  - Restructuring @APRSIS into @JS8NET
  - Missed frame computation should happen after 1 period...lets
    set it to 1.5 periods for now
  - Ellipses check checks text first
  - Added substitute flag in dictionary compression...for later
  - Added mutex for critical regions in the decode process
  - Added guard pattern
  - Cleanup playSoundFile
  - Code cleanup
  - Clean up decoder fortran
  - Added a few special group callsigns
  - Further mutex for decode done to avoid race conditions across threads
  - Updated mac bundle identifier
  - Added debugging fromthe decoder
  - Move decoder process handling to separate thread to avoid exhaustuion
  - Initial reworking of js8 decoder threading and scheduling
  - Fixed the decoder deadlock.
  - Decoder should wait 2 seconds after transmit before trying to decode again
  - Removed the DecodedText snr limitation
  - Fixed issue with datetime formatting in ALL.txt and duplicate entries
    in ALL.txt
  - Fixed notification audio to not produce static by buffering the entire
    file ahead of time before playing
  - Fixed #249: log dialog covering error message
  - Added some unicode escaping routines for later
  - Fixed #245: Added partial support for a subset of latin1 charset
  - Default UDP server port changed to 2242
  - Added error and finished signals to the decoder process
  - Updated decoder subprocess error handling to restart instead of crash the app
  - Updated udp.py with the new default port
  - Fixed segfault in jsc compression code
  - Fixed issue with callsign selection
  - Fixed lag in notifications by added a byte stream cache
  - Fixed array alignment in decoder
* Sat Nov 16 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.0.0-rc5
  Fixed #223: compound callsign directed text coloring
  Fixed Show Band Heartbeats / Acks by default
  Attempt decoder process recovery on hang until I determine why its hanging
  Detector buffer position should be 0 after clear
  Updated decode locking. Removed DecodeButton and OptimizingProgressDialog
  Submode should be initd
  Added locking debug
  Added better initialization. Added skipping decodes while not monitoring.
  Delay first decode until start of the next period on startup
  Fixed initial decode after transmit caused by transmit dead air
  Added output option for debug statements to the command line
  Fixed newline processing
  Fixed enter keypress for proper handling
  Fixed #71: newline supported in 2.0 messages
  Hide save audio functionality until its no longer broken
  Turn off decoder debugging by default unless in debug mode
  Restructuring @APRSIS into @JS8NET
* Thu Nov 14 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.0.0-rc4
  bug fix
* Fri Nov  8 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.0.0-rc3
  decode all speeds at once
* Thu Oct 24 2019 Walter Fey <dl8fcl@darc.de>
- update to version 2.0.0-rc2
  Fixed VIA for Joe
  Backwards compatibility to parse VIA or DE
  Fixed double printing (... I think ...)
  Further expanding the rx threshold window
  Fixed time drifting sync for fast and turbo modes
  Fixed trailing space on text restore
  Fixed trailing space on AGN text
  Added tooltips for name and comment fields in Call Activity
  Refactor decoder output to include which submode is decoded so we could eventually run three
  Decoded text needs padding for columns
  Fixed modename references
  Fixed mode button display when in qso and pause hbs enabled
  Fixed naming of modename to speed
  Refactor + some comments for better understanding of the dec_data structure
  Dedupe in the decoder b4 move fqso to top of list
  Updated decode menu labels to not be confusing with mode speeds
  Ripped out echograph code as it was causing strange linking issues with the MacOS compiler
* Tue Jul 16 2019 Walter Fey <dl8fcl@darc.de>
- Fix for Tumbleweed build
* Wed Jun 19 2019 Walter Fey <dl8fcl@darc.de>
- no-return-in-nonvoid-function error in post build checks fixed
* Wed Jun 19 2019 Walter Fey <dl8fcl@darc.de>
- update to version 1.1.0
  - Fixed #119: hold PTT open if more frames are available (experimental
    patch from Peter GM8JCF)
  - Added a configuration checkbox for holding PTT
  - Cleaning up the PTT logic to make it easier to reason about
  - Fixed #185: message inbox should show the full message text
  - Fixed #182: added shortcuts to focus different areas of the app
  - Fixed: #181: Removed ref spec from waterfall
  - Fixed #178: include callsign by default for all messages, including standard
    messages. Added an option in the configuration to revert to the original
    behavior of no identification
  - Fixed up conditionals in commons.h
  - Added total transmit duration to send button
  - Added spotting of callsign when sending forced identify data prefix
  - Added N3FJP logging integration natively.
  - Added selected text in the RX window to be placed in the comments of the
    log window.
  - Updated log window look. Fixed bug in n3fjp logging
  - Updated log window layout and tab ordering. Wired up log 'now' buttons
  - Added log window population via double click of words in the rx window
  - Updated N3FJP integration to send the correct data
  - Log RX text should append instead of overwrite
  - Implemented basic logging of additional fields support based on ADIF
  - Write additional fields to adi log file
  - Added n3fjp mapping of custom fields
  - Blank value for custom fields dropdown should be first
  - Fixed up tab ordering for log window
  - Added warning message for failed log to n3fjp
  - Updated log window to maintain contents if the call selected does not change
  - Fixed layout.removeRow for old versions of Qt
  - Tweaked CQ encoding to include CQ FD, dropped CQCQCQ
  - Cleaned up log window and fixed tab ordering
  - Updated log window layout, button placement, and tab ordering
  - Added app defined log fields and editable comboboxes
  - Update the log window geometry
  - Fixed #14: Added caching of call activity and rx activity between
    application restarts
  - Added an option to configuration for persistent band/call/rx activity
  - Update to Call Activity to pull grid from log if the station has not
    transmitted their grid yet
* Fri May  3 2019 Walter Fey <dl8fcl@darc.de>
- update to version 1.0.1
  Fixed #159: removed unicode quotes from GPL so it can be read on
    acient windows machines.
  Fixed #176: remove avg time drift as it is an unreliable means for
    computing drift
  Fixed #177: autoreply off at startup if no grid or callsign is defined
  Updated customization labels
  Fixed bug with EOT character replacement
  End of transmission character is required
  Fixed #171, #172, #173: Fix Mojave audio permissions
  Lowercase de.
  Deprecated the Electric Arrow. Added customization option for EOT character.
  Updated buffer processing to process incomplete message buffers
  Added DIRECTED.TXT log for all directed messages
  Updated callsign and grid configuration to trim whitespace
  Fixed ordering of MacOS commands
  Fixed MacOS Readme
* Mon Apr  1 2019 Walter Fey <dl8fcl@darc.de>
- update to version 1.0.0
  Fixed #160: HB ACKs not stopped during QSO with the new checkmark setting
  Fixed QSO start time when you selected a station callsign
  Fixed #163: Removed DATA from logging
  Fixed defaults for HB and CQ repeat menus
  Updated to spot local station information once every 15 minutes
  Updated labeling for disabled HB ack
  Updated label to be JS8NET
  Updated icon tooltip in Call Activity
  Updated copyright
  Updated about repository URL
* Wed Mar 27 2019 Walter Fey <dl8fcl@darc.de>
- update to version 1.0.0-rc3
  Moved wsjtx qt creator to js8call
  Merged patch to fix #97
  Removed extraneous logbook debug statements
  Added telephone icon for CQs. Added tooltip for last logged date
  Only show CQ icon for 5 minutes
  Change SNR for HB ACK. Default to HB hidden
  Bump to RC3
  Fixed #148: configuration tab ordering
  Fixed #142: callsign selected is an indicator for qso start time
  Added click of callsign to open profile
  A few better tooltips
  Fixed #94: swap heard graph on band change
  Added explicit setting for automatically acknowledging heartbeat messages
  Added spotting to spot.js8call.com for future network data
  Updated configuration reporting labeling to include JS8 Network
  Changed my mind. HB ACKs should include SNR
  Updated heartbeat ack labeling
  Updated SpotClient to send local data at least once every 5 minutes
  Added by.grid to SpotClient spots
  Added spotting of messages directed to @JS8NET
* Tue Mar 12 2019 Walter Fey <dl8fcl@darc.de>
- update to version 1.0.0-rc2
  Fixed #76: added tone output to API
  Fixed #135: query commands through relay. Changed the QUERY CALL
    reply format so as to not confuse folks with random ACKs.
  Fixed & cleaned up empty dB formatting in the call and band
    activity tables.
  Fixed #129: relays now use 'VIA' as the intermediate text for relay
    path computation instead of 'DE'.
  Fixed also relays still being ACKed while relay messaging was disabled.
  Added tooltip with absolute date for age columns
  Added NACK command for future implementation
  Added log details columns (worked before, name, and comment) to
    call activity table
  Added DIT DIT short message
* Thu Feb 21 2019 dl8fcl@darc.de
- update to version 1.0.0-rc1
  /P callsign suffix can now be transmitted in a single frame for all
    non-compound callsigns (meaning KN4CRD/P: JY1/P SNR? would
    transmit in one frame). Huzzah!
  HB is now paused while you are "in QSO" (as in, when you have a
  callsign selected) and unpaused when you deselect your QSO partner.
  If you open the message inbox without a callsign selected you will
  be able to view "All" messages.
  You can now store a message at your local station for somebody else.
  You can now add a custom interval for HB and CQ messages
  (up to 1440 minutes...i.e., once per day)
  The "QTH?" command is now called "INFO?" which contains _generic_
  station information (antenna, rig, qth, power, anything).
  There are now some pre-configured group names that can be transmitted
  in one frame (@JS8NET, @GROUP1, etc). Check the documentation for more!
  HEARING messages now parse callsigns and add them to the callsign tooltips
  Fixed a bunch of bugs related to printing of ACKs, sorting of frequencies, etc.
* Wed Feb 20 2019 dl8fcl@darc.de
- a tag added, to show on pskreporter who is using this version
* Sun Feb 10 2019 dl8fcl@darc.de
- update to version 0.14.1
  Fixes PTT configuration for RTS/DTS setups.
  Fixes the HB AUTO SPOT display issue
  Adds the MSG [ID] directed message to the menu.
  Added a suggested 2m frequency to the list 144.178 MHz.
* Fri Feb  8 2019 dl8fcl@darc.de
- update to version 0.14.0
  Bugfixes
  Added tooltip to frequency indicator
  Unify the fonts used in the frequency panel
  Fixed height for labels in frequency panel
  Refactor create message transmit queue to be more straightforward.
  Added tooltip tweaks for band activity
  Process GRID commands for everybody
  Clear tx queue before warning message too.
  Removed QTC as it was confusing and redundant. QTH is now the 'station message'
  Added CMD. Fixed sending of spots over the network API.
  Message id for response to query and message id for a generic message retreival
  Working through QUERY MSG [id] and MSG commands to make it easier to work with the inbox
  Added ability to relay MSG and MSG TO commands
  Added baseline message history window
  Added callsign blacklist to complement the whitelist
  Working through message window wireup
  Disabled message history while experimenting
  Added message to dummy data for testing
  Fixed dummy data message composition
  Updated message inbox window for future work
* Thu Jan 24 2019 dl8fcl@darc.de
- update to version 0.13.0
  Tons of bugfixes and tweaks.
  Keeps track of which stations can hear which.
  Hide the status bar.
  Send relay messages "to" a group callsign.
  HB and the STATUS command are now closer related.
  New whitelist setting.
  CQ FIELD and CQ CONTEST single frame CQ transmissions.
  A subset of commands can now be relayed to a station with an
  automatic relay response.
  Frequency control changes.
  Store a message at an intermediate station.
* Thu Jan  3 2019 dl8fcl@darc.de
- update to version 0.12.0
* Sun Dec 30 2018 dl8fcl@darc.de
- spec file cleanup
* Sun Dec 30 2018 dl8fcl@darc.de
- patch to not build/install redundant binaries with hamlib
  found at fedorainfracloud.org from Richard Shaw(hobbes1069)
* Sun Dec 30 2018 dl8fcl@darc.de
- import into buildservice
